# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class GroupProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'access_activity_log': 'bool',

        'access_and_manage_certificates': 'bool',

        'access_and_manage_dns': 'bool',

        'access_and_manage_monitoring': 'bool',

        'create_backup_unit': 'bool',

        'create_data_center': 'bool',

        'create_flow_log': 'bool',

        'create_internet_access': 'bool',

        'create_k8s_cluster': 'bool',

        'create_pcc': 'bool',

        'create_snapshot': 'bool',

        'manage_dbaas': 'bool',

        'manage_dataplatform': 'bool',

        'manage_registry': 'bool',

        'name': 'str',

        'reserve_ip': 'bool',

        's3_privilege': 'bool',
    }

    attribute_map = {

        'access_activity_log': 'accessActivityLog',

        'access_and_manage_certificates': 'accessAndManageCertificates',

        'access_and_manage_dns': 'accessAndManageDns',

        'access_and_manage_monitoring': 'accessAndManageMonitoring',

        'create_backup_unit': 'createBackupUnit',

        'create_data_center': 'createDataCenter',

        'create_flow_log': 'createFlowLog',

        'create_internet_access': 'createInternetAccess',

        'create_k8s_cluster': 'createK8sCluster',

        'create_pcc': 'createPcc',

        'create_snapshot': 'createSnapshot',

        'manage_dbaas': 'manageDBaaS',

        'manage_dataplatform': 'manageDataplatform',

        'manage_registry': 'manageRegistry',

        'name': 'name',

        'reserve_ip': 'reserveIp',

        's3_privilege': 's3Privilege',
    }

    def __init__(self, access_activity_log=None, access_and_manage_certificates=None, access_and_manage_dns=None, access_and_manage_monitoring=None, create_backup_unit=None, create_data_center=None, create_flow_log=None, create_internet_access=None, create_k8s_cluster=None, create_pcc=None, create_snapshot=None, manage_dbaas=None, manage_dataplatform=None, manage_registry=None, name=None, reserve_ip=None, s3_privilege=None, local_vars_configuration=None):  # noqa: E501
        """GroupProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_activity_log = None
        self._access_and_manage_certificates = None
        self._access_and_manage_dns = None
        self._access_and_manage_monitoring = None
        self._create_backup_unit = None
        self._create_data_center = None
        self._create_flow_log = None
        self._create_internet_access = None
        self._create_k8s_cluster = None
        self._create_pcc = None
        self._create_snapshot = None
        self._manage_dbaas = None
        self._manage_dataplatform = None
        self._manage_registry = None
        self._name = None
        self._reserve_ip = None
        self._s3_privilege = None
        self.discriminator = None

        if access_activity_log is not None:
            self.access_activity_log = access_activity_log
        if access_and_manage_certificates is not None:
            self.access_and_manage_certificates = access_and_manage_certificates
        if access_and_manage_dns is not None:
            self.access_and_manage_dns = access_and_manage_dns
        if access_and_manage_monitoring is not None:
            self.access_and_manage_monitoring = access_and_manage_monitoring
        if create_backup_unit is not None:
            self.create_backup_unit = create_backup_unit
        if create_data_center is not None:
            self.create_data_center = create_data_center
        if create_flow_log is not None:
            self.create_flow_log = create_flow_log
        if create_internet_access is not None:
            self.create_internet_access = create_internet_access
        if create_k8s_cluster is not None:
            self.create_k8s_cluster = create_k8s_cluster
        if create_pcc is not None:
            self.create_pcc = create_pcc
        if create_snapshot is not None:
            self.create_snapshot = create_snapshot
        if manage_dbaas is not None:
            self.manage_dbaas = manage_dbaas
        if manage_dataplatform is not None:
            self.manage_dataplatform = manage_dataplatform
        if manage_registry is not None:
            self.manage_registry = manage_registry
        if name is not None:
            self.name = name
        if reserve_ip is not None:
            self.reserve_ip = reserve_ip
        if s3_privilege is not None:
            self.s3_privilege = s3_privilege


    @property
    def access_activity_log(self):
        """Gets the access_activity_log of this GroupProperties.  # noqa: E501

        Activity log access privilege.  # noqa: E501

        :return: The access_activity_log of this GroupProperties.  # noqa: E501
        :rtype: bool
        """
        return self._access_activity_log

    @access_activity_log.setter
    def access_activity_log(self, access_activity_log):
        """Sets the access_activity_log of this GroupProperties.

        Activity log access privilege.  # noqa: E501

        :param access_activity_log: The access_activity_log of this GroupProperties.  # noqa: E501
        :type access_activity_log: bool
        """

        self._access_activity_log = access_activity_log

    @property
    def access_and_manage_certificates(self):
        """Gets the access_and_manage_certificates of this GroupProperties.  # noqa: E501

        Privilege for a group to access and manage certificates.  # noqa: E501

        :return: The access_and_manage_certificates of this GroupProperties.  # noqa: E501
        :rtype: bool
        """
        return self._access_and_manage_certificates

    @access_and_manage_certificates.setter
    def access_and_manage_certificates(self, access_and_manage_certificates):
        """Sets the access_and_manage_certificates of this GroupProperties.

        Privilege for a group to access and manage certificates.  # noqa: E501

        :param access_and_manage_certificates: The access_and_manage_certificates of this GroupProperties.  # noqa: E501
        :type access_and_manage_certificates: bool
        """

        self._access_and_manage_certificates = access_and_manage_certificates

    @property
    def access_and_manage_dns(self):
        """Gets the access_and_manage_dns of this GroupProperties.  # noqa: E501

        Privilege for a group to access and manage dns records.  # noqa: E501

        :return: The access_and_manage_dns of this GroupProperties.  # noqa: E501
        :rtype: bool
        """
        return self._access_and_manage_dns

    @access_and_manage_dns.setter
    def access_and_manage_dns(self, access_and_manage_dns):
        """Sets the access_and_manage_dns of this GroupProperties.

        Privilege for a group to access and manage dns records.  # noqa: E501

        :param access_and_manage_dns: The access_and_manage_dns of this GroupProperties.  # noqa: E501
        :type access_and_manage_dns: bool
        """

        self._access_and_manage_dns = access_and_manage_dns

    @property
    def access_and_manage_monitoring(self):
        """Gets the access_and_manage_monitoring of this GroupProperties.  # noqa: E501

        Privilege for a group to access and manage monitoring related functionality (access metrics, CRUD on alarms, alarm-actions etc) using Monotoring-as-a-Service (MaaS).  # noqa: E501

        :return: The access_and_manage_monitoring of this GroupProperties.  # noqa: E501
        :rtype: bool
        """
        return self._access_and_manage_monitoring

    @access_and_manage_monitoring.setter
    def access_and_manage_monitoring(self, access_and_manage_monitoring):
        """Sets the access_and_manage_monitoring of this GroupProperties.

        Privilege for a group to access and manage monitoring related functionality (access metrics, CRUD on alarms, alarm-actions etc) using Monotoring-as-a-Service (MaaS).  # noqa: E501

        :param access_and_manage_monitoring: The access_and_manage_monitoring of this GroupProperties.  # noqa: E501
        :type access_and_manage_monitoring: bool
        """

        self._access_and_manage_monitoring = access_and_manage_monitoring

    @property
    def create_backup_unit(self):
        """Gets the create_backup_unit of this GroupProperties.  # noqa: E501

        Create backup unit privilege.  # noqa: E501

        :return: The create_backup_unit of this GroupProperties.  # noqa: E501
        :rtype: bool
        """
        return self._create_backup_unit

    @create_backup_unit.setter
    def create_backup_unit(self, create_backup_unit):
        """Sets the create_backup_unit of this GroupProperties.

        Create backup unit privilege.  # noqa: E501

        :param create_backup_unit: The create_backup_unit of this GroupProperties.  # noqa: E501
        :type create_backup_unit: bool
        """

        self._create_backup_unit = create_backup_unit

    @property
    def create_data_center(self):
        """Gets the create_data_center of this GroupProperties.  # noqa: E501

        Create data center privilege.  # noqa: E501

        :return: The create_data_center of this GroupProperties.  # noqa: E501
        :rtype: bool
        """
        return self._create_data_center

    @create_data_center.setter
    def create_data_center(self, create_data_center):
        """Sets the create_data_center of this GroupProperties.

        Create data center privilege.  # noqa: E501

        :param create_data_center: The create_data_center of this GroupProperties.  # noqa: E501
        :type create_data_center: bool
        """

        self._create_data_center = create_data_center

    @property
    def create_flow_log(self):
        """Gets the create_flow_log of this GroupProperties.  # noqa: E501

        Create Flow Logs privilege.  # noqa: E501

        :return: The create_flow_log of this GroupProperties.  # noqa: E501
        :rtype: bool
        """
        return self._create_flow_log

    @create_flow_log.setter
    def create_flow_log(self, create_flow_log):
        """Sets the create_flow_log of this GroupProperties.

        Create Flow Logs privilege.  # noqa: E501

        :param create_flow_log: The create_flow_log of this GroupProperties.  # noqa: E501
        :type create_flow_log: bool
        """

        self._create_flow_log = create_flow_log

    @property
    def create_internet_access(self):
        """Gets the create_internet_access of this GroupProperties.  # noqa: E501

        Create internet access privilege.  # noqa: E501

        :return: The create_internet_access of this GroupProperties.  # noqa: E501
        :rtype: bool
        """
        return self._create_internet_access

    @create_internet_access.setter
    def create_internet_access(self, create_internet_access):
        """Sets the create_internet_access of this GroupProperties.

        Create internet access privilege.  # noqa: E501

        :param create_internet_access: The create_internet_access of this GroupProperties.  # noqa: E501
        :type create_internet_access: bool
        """

        self._create_internet_access = create_internet_access

    @property
    def create_k8s_cluster(self):
        """Gets the create_k8s_cluster of this GroupProperties.  # noqa: E501

        Create Kubernetes cluster privilege.  # noqa: E501

        :return: The create_k8s_cluster of this GroupProperties.  # noqa: E501
        :rtype: bool
        """
        return self._create_k8s_cluster

    @create_k8s_cluster.setter
    def create_k8s_cluster(self, create_k8s_cluster):
        """Sets the create_k8s_cluster of this GroupProperties.

        Create Kubernetes cluster privilege.  # noqa: E501

        :param create_k8s_cluster: The create_k8s_cluster of this GroupProperties.  # noqa: E501
        :type create_k8s_cluster: bool
        """

        self._create_k8s_cluster = create_k8s_cluster

    @property
    def create_pcc(self):
        """Gets the create_pcc of this GroupProperties.  # noqa: E501

        Create pcc privilege.  # noqa: E501

        :return: The create_pcc of this GroupProperties.  # noqa: E501
        :rtype: bool
        """
        return self._create_pcc

    @create_pcc.setter
    def create_pcc(self, create_pcc):
        """Sets the create_pcc of this GroupProperties.

        Create pcc privilege.  # noqa: E501

        :param create_pcc: The create_pcc of this GroupProperties.  # noqa: E501
        :type create_pcc: bool
        """

        self._create_pcc = create_pcc

    @property
    def create_snapshot(self):
        """Gets the create_snapshot of this GroupProperties.  # noqa: E501

        Create snapshot privilege.  # noqa: E501

        :return: The create_snapshot of this GroupProperties.  # noqa: E501
        :rtype: bool
        """
        return self._create_snapshot

    @create_snapshot.setter
    def create_snapshot(self, create_snapshot):
        """Sets the create_snapshot of this GroupProperties.

        Create snapshot privilege.  # noqa: E501

        :param create_snapshot: The create_snapshot of this GroupProperties.  # noqa: E501
        :type create_snapshot: bool
        """

        self._create_snapshot = create_snapshot

    @property
    def manage_dbaas(self):
        """Gets the manage_dbaas of this GroupProperties.  # noqa: E501

        Privilege for a group to manage DBaaS related functionality.  # noqa: E501

        :return: The manage_dbaas of this GroupProperties.  # noqa: E501
        :rtype: bool
        """
        return self._manage_dbaas

    @manage_dbaas.setter
    def manage_dbaas(self, manage_dbaas):
        """Sets the manage_dbaas of this GroupProperties.

        Privilege for a group to manage DBaaS related functionality.  # noqa: E501

        :param manage_dbaas: The manage_dbaas of this GroupProperties.  # noqa: E501
        :type manage_dbaas: bool
        """

        self._manage_dbaas = manage_dbaas

    @property
    def manage_dataplatform(self):
        """Gets the manage_dataplatform of this GroupProperties.  # noqa: E501

        Privilege for a group to access and manage the Data Platform.  # noqa: E501

        :return: The manage_dataplatform of this GroupProperties.  # noqa: E501
        :rtype: bool
        """
        return self._manage_dataplatform

    @manage_dataplatform.setter
    def manage_dataplatform(self, manage_dataplatform):
        """Sets the manage_dataplatform of this GroupProperties.

        Privilege for a group to access and manage the Data Platform.  # noqa: E501

        :param manage_dataplatform: The manage_dataplatform of this GroupProperties.  # noqa: E501
        :type manage_dataplatform: bool
        """

        self._manage_dataplatform = manage_dataplatform

    @property
    def manage_registry(self):
        """Gets the manage_registry of this GroupProperties.  # noqa: E501

        Privilege for group accessing container registry related functionality.  # noqa: E501

        :return: The manage_registry of this GroupProperties.  # noqa: E501
        :rtype: bool
        """
        return self._manage_registry

    @manage_registry.setter
    def manage_registry(self, manage_registry):
        """Sets the manage_registry of this GroupProperties.

        Privilege for group accessing container registry related functionality.  # noqa: E501

        :param manage_registry: The manage_registry of this GroupProperties.  # noqa: E501
        :type manage_registry: bool
        """

        self._manage_registry = manage_registry

    @property
    def name(self):
        """Gets the name of this GroupProperties.  # noqa: E501

        The name of the resource.  # noqa: E501

        :return: The name of this GroupProperties.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GroupProperties.

        The name of the resource.  # noqa: E501

        :param name: The name of this GroupProperties.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def reserve_ip(self):
        """Gets the reserve_ip of this GroupProperties.  # noqa: E501

        Reserve IP block privilege.  # noqa: E501

        :return: The reserve_ip of this GroupProperties.  # noqa: E501
        :rtype: bool
        """
        return self._reserve_ip

    @reserve_ip.setter
    def reserve_ip(self, reserve_ip):
        """Sets the reserve_ip of this GroupProperties.

        Reserve IP block privilege.  # noqa: E501

        :param reserve_ip: The reserve_ip of this GroupProperties.  # noqa: E501
        :type reserve_ip: bool
        """

        self._reserve_ip = reserve_ip

    @property
    def s3_privilege(self):
        """Gets the s3_privilege of this GroupProperties.  # noqa: E501

        S3 privilege.  # noqa: E501

        :return: The s3_privilege of this GroupProperties.  # noqa: E501
        :rtype: bool
        """
        return self._s3_privilege

    @s3_privilege.setter
    def s3_privilege(self, s3_privilege):
        """Sets the s3_privilege of this GroupProperties.

        S3 privilege.  # noqa: E501

        :param s3_privilege: The s3_privilege of this GroupProperties.  # noqa: E501
        :type s3_privilege: bool
        """

        self._s3_privilege = s3_privilege
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GroupProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GroupProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class IpBlockProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'ip_consumers': 'list[IpConsumer]',

        'ips': 'list[str]',

        'location': 'str',

        'name': 'str',

        'size': 'int',
    }

    attribute_map = {

        'ip_consumers': 'ipConsumers',

        'ips': 'ips',

        'location': 'location',

        'name': 'name',

        'size': 'size',
    }

    def __init__(self, ip_consumers=None, ips=None, location=None, name=None, size=None, local_vars_configuration=None):  # noqa: E501
        """IpBlockProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ip_consumers = None
        self._ips = None
        self._location = None
        self._name = None
        self._size = None
        self.discriminator = None

        if ip_consumers is not None:
            self.ip_consumers = ip_consumers
        if ips is not None:
            self.ips = ips
        self.location = location
        if name is not None:
            self.name = name
        self.size = size


    @property
    def ip_consumers(self):
        """Gets the ip_consumers of this IpBlockProperties.  # noqa: E501

        Read-Only attribute. Lists consumption detail for an individual IP  # noqa: E501

        :return: The ip_consumers of this IpBlockProperties.  # noqa: E501
        :rtype: list[IpConsumer]
        """
        return self._ip_consumers

    @ip_consumers.setter
    def ip_consumers(self, ip_consumers):
        """Sets the ip_consumers of this IpBlockProperties.

        Read-Only attribute. Lists consumption detail for an individual IP  # noqa: E501

        :param ip_consumers: The ip_consumers of this IpBlockProperties.  # noqa: E501
        :type ip_consumers: list[IpConsumer]
        """

        self._ip_consumers = ip_consumers

    @property
    def ips(self):
        """Gets the ips of this IpBlockProperties.  # noqa: E501

        Collection of IPs, associated with the IP Block.  # noqa: E501

        :return: The ips of this IpBlockProperties.  # noqa: E501
        :rtype: list[str]
        """
        return self._ips

    @ips.setter
    def ips(self, ips):
        """Sets the ips of this IpBlockProperties.

        Collection of IPs, associated with the IP Block.  # noqa: E501

        :param ips: The ips of this IpBlockProperties.  # noqa: E501
        :type ips: list[str]
        """

        self._ips = ips

    @property
    def location(self):
        """Gets the location of this IpBlockProperties.  # noqa: E501

        Location of that IP block. Property cannot be modified after it is created (disallowed in update requests).  # noqa: E501

        :return: The location of this IpBlockProperties.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this IpBlockProperties.

        Location of that IP block. Property cannot be modified after it is created (disallowed in update requests).  # noqa: E501

        :param location: The location of this IpBlockProperties.  # noqa: E501
        :type location: str
        """
        if self.local_vars_configuration.client_side_validation and location is None:  # noqa: E501
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    @property
    def name(self):
        """Gets the name of this IpBlockProperties.  # noqa: E501

        The name of the  resource.  # noqa: E501

        :return: The name of this IpBlockProperties.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IpBlockProperties.

        The name of the  resource.  # noqa: E501

        :param name: The name of this IpBlockProperties.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def size(self):
        """Gets the size of this IpBlockProperties.  # noqa: E501

        The size of the IP block.  # noqa: E501

        :return: The size of this IpBlockProperties.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this IpBlockProperties.

        The size of the IP block.  # noqa: E501

        :param size: The size of this IpBlockProperties.  # noqa: E501
        :type size: int
        """
        if self.local_vars_configuration.client_side_validation and size is None:  # noqa: E501
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IpBlockProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IpBlockProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class TargetGroupHttpHealthCheck(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'match_type': 'str',

        'method': 'str',

        'negate': 'bool',

        'path': 'str',

        'regex': 'bool',

        'response': 'str',
    }

    attribute_map = {

        'match_type': 'matchType',

        'method': 'method',

        'negate': 'negate',

        'path': 'path',

        'regex': 'regex',

        'response': 'response',
    }

    def __init__(self, match_type=None, method=None, negate=None, path=None, regex=None, response=None, local_vars_configuration=None):  # noqa: E501
        """TargetGroupHttpHealthCheck - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._match_type = None
        self._method = None
        self._negate = None
        self._path = None
        self._regex = None
        self._response = None
        self.discriminator = None

        self.match_type = match_type
        if method is not None:
            self.method = method
        if negate is not None:
            self.negate = negate
        if path is not None:
            self.path = path
        if regex is not None:
            self.regex = regex
        self.response = response


    @property
    def match_type(self):
        """Gets the match_type of this TargetGroupHttpHealthCheck.  # noqa: E501

        Specify the target's response type to match ALB's request.  # noqa: E501

        :return: The match_type of this TargetGroupHttpHealthCheck.  # noqa: E501
        :rtype: str
        """
        return self._match_type

    @match_type.setter
    def match_type(self, match_type):
        """Sets the match_type of this TargetGroupHttpHealthCheck.

        Specify the target's response type to match ALB's request.  # noqa: E501

        :param match_type: The match_type of this TargetGroupHttpHealthCheck.  # noqa: E501
        :type match_type: str
        """
        if self.local_vars_configuration.client_side_validation and match_type is None:  # noqa: E501
            raise ValueError("Invalid value for `match_type`, must not be `None`")  # noqa: E501
        allowed_values = ["STATUS_CODE", "RESPONSE_BODY"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and match_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `match_type` ({0}), must be one of {1}"  # noqa: E501
                .format(match_type, allowed_values)
            )

        self._match_type = match_type

    @property
    def method(self):
        """Gets the method of this TargetGroupHttpHealthCheck.  # noqa: E501

        The method used for the health check request.  # noqa: E501

        :return: The method of this TargetGroupHttpHealthCheck.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this TargetGroupHttpHealthCheck.

        The method used for the health check request.  # noqa: E501

        :param method: The method of this TargetGroupHttpHealthCheck.  # noqa: E501
        :type method: str
        """
        allowed_values = ["HEAD", "PUT", "POST", "GET", "TRACE", "PATCH", "OPTIONS"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and method not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `method` ({0}), must be one of {1}"  # noqa: E501
                .format(method, allowed_values)
            )

        self._method = method

    @property
    def negate(self):
        """Gets the negate of this TargetGroupHttpHealthCheck.  # noqa: E501

        Specifies whether to negate an individual entry; the default value is 'FALSE'.  # noqa: E501

        :return: The negate of this TargetGroupHttpHealthCheck.  # noqa: E501
        :rtype: bool
        """
        return self._negate

    @negate.setter
    def negate(self, negate):
        """Sets the negate of this TargetGroupHttpHealthCheck.

        Specifies whether to negate an individual entry; the default value is 'FALSE'.  # noqa: E501

        :param negate: The negate of this TargetGroupHttpHealthCheck.  # noqa: E501
        :type negate: bool
        """

        self._negate = negate

    @property
    def path(self):
        """Gets the path of this TargetGroupHttpHealthCheck.  # noqa: E501

        The destination URL for HTTP the health check; the default is '/'.  # noqa: E501

        :return: The path of this TargetGroupHttpHealthCheck.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this TargetGroupHttpHealthCheck.

        The destination URL for HTTP the health check; the default is '/'.  # noqa: E501

        :param path: The path of this TargetGroupHttpHealthCheck.  # noqa: E501
        :type path: str
        """

        self._path = path

    @property
    def regex(self):
        """Gets the regex of this TargetGroupHttpHealthCheck.  # noqa: E501

        Specifies whether to use a regular expression to parse the response body; the default value is 'FALSE'.  By using regular expressions, you can flexibly customize the expected response from a healthy server.  # noqa: E501

        :return: The regex of this TargetGroupHttpHealthCheck.  # noqa: E501
        :rtype: bool
        """
        return self._regex

    @regex.setter
    def regex(self, regex):
        """Sets the regex of this TargetGroupHttpHealthCheck.

        Specifies whether to use a regular expression to parse the response body; the default value is 'FALSE'.  By using regular expressions, you can flexibly customize the expected response from a healthy server.  # noqa: E501

        :param regex: The regex of this TargetGroupHttpHealthCheck.  # noqa: E501
        :type regex: bool
        """

        self._regex = regex

    @property
    def response(self):
        """Gets the response of this TargetGroupHttpHealthCheck.  # noqa: E501

        The response returned by the request. It can be a status code or a response body depending on the definition of 'matchType'.  # noqa: E501

        :return: The response of this TargetGroupHttpHealthCheck.  # noqa: E501
        :rtype: str
        """
        return self._response

    @response.setter
    def response(self, response):
        """Sets the response of this TargetGroupHttpHealthCheck.

        The response returned by the request. It can be a status code or a response body depending on the definition of 'matchType'.  # noqa: E501

        :param response: The response of this TargetGroupHttpHealthCheck.  # noqa: E501
        :type response: str
        """
        if self.local_vars_configuration.client_side_validation and response is None:  # noqa: E501
            raise ValueError("Invalid value for `response`, must not be `None`")  # noqa: E501

        self._response = response
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TargetGroupHttpHealthCheck):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TargetGroupHttpHealthCheck):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class DatacenterProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'cpu_architecture': 'list[CpuArchitectureProperties]',

        'description': 'str',

        'features': 'list[str]',

        'ipv6_cidr_block': 'str',

        'location': 'str',

        'name': 'str',

        'sec_auth_protection': 'bool',

        'version': 'int',
    }

    attribute_map = {

        'cpu_architecture': 'cpuArchitecture',

        'description': 'description',

        'features': 'features',

        'ipv6_cidr_block': 'ipv6CidrBlock',

        'location': 'location',

        'name': 'name',

        'sec_auth_protection': 'secAuthProtection',

        'version': 'version',
    }

    def __init__(self, cpu_architecture=None, description=None, features=None, ipv6_cidr_block=None, location=None, name=None, sec_auth_protection=None, version=None, local_vars_configuration=None):  # noqa: E501
        """DatacenterProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cpu_architecture = None
        self._description = None
        self._features = None
        self._ipv6_cidr_block = None
        self._location = None
        self._name = None
        self._sec_auth_protection = None
        self._version = None
        self.discriminator = None

        if cpu_architecture is not None:
            self.cpu_architecture = cpu_architecture
        if description is not None:
            self.description = description
        if features is not None:
            self.features = features
        self.ipv6_cidr_block = ipv6_cidr_block
        self.location = location
        if name is not None:
            self.name = name
        if sec_auth_protection is not None:
            self.sec_auth_protection = sec_auth_protection
        if version is not None:
            self.version = version


    @property
    def cpu_architecture(self):
        """Gets the cpu_architecture of this DatacenterProperties.  # noqa: E501

        Array of features and CPU families available in a location  # noqa: E501

        :return: The cpu_architecture of this DatacenterProperties.  # noqa: E501
        :rtype: list[CpuArchitectureProperties]
        """
        return self._cpu_architecture

    @cpu_architecture.setter
    def cpu_architecture(self, cpu_architecture):
        """Sets the cpu_architecture of this DatacenterProperties.

        Array of features and CPU families available in a location  # noqa: E501

        :param cpu_architecture: The cpu_architecture of this DatacenterProperties.  # noqa: E501
        :type cpu_architecture: list[CpuArchitectureProperties]
        """

        self._cpu_architecture = cpu_architecture

    @property
    def description(self):
        """Gets the description of this DatacenterProperties.  # noqa: E501

        A description for the datacenter, such as staging, production.  # noqa: E501

        :return: The description of this DatacenterProperties.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DatacenterProperties.

        A description for the datacenter, such as staging, production.  # noqa: E501

        :param description: The description of this DatacenterProperties.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def features(self):
        """Gets the features of this DatacenterProperties.  # noqa: E501

        List of features supported by the location where this data center is provisioned.  # noqa: E501

        :return: The features of this DatacenterProperties.  # noqa: E501
        :rtype: list[str]
        """
        return self._features

    @features.setter
    def features(self, features):
        """Sets the features of this DatacenterProperties.

        List of features supported by the location where this data center is provisioned.  # noqa: E501

        :param features: The features of this DatacenterProperties.  # noqa: E501
        :type features: list[str]
        """

        self._features = features

    @property
    def ipv6_cidr_block(self):
        """Gets the ipv6_cidr_block of this DatacenterProperties.  # noqa: E501

        This value is either 'null' or contains an automatically-assigned /56 IPv6 CIDR block if IPv6 is enabled on this virtual data center. It can neither be changed nor removed.  # noqa: E501

        :return: The ipv6_cidr_block of this DatacenterProperties.  # noqa: E501
        :rtype: str
        """
        return self._ipv6_cidr_block

    @ipv6_cidr_block.setter
    def ipv6_cidr_block(self, ipv6_cidr_block):
        """Sets the ipv6_cidr_block of this DatacenterProperties.

        This value is either 'null' or contains an automatically-assigned /56 IPv6 CIDR block if IPv6 is enabled on this virtual data center. It can neither be changed nor removed.  # noqa: E501

        :param ipv6_cidr_block: The ipv6_cidr_block of this DatacenterProperties.  # noqa: E501
        :type ipv6_cidr_block: str
        """

        self._ipv6_cidr_block = ipv6_cidr_block

    @property
    def location(self):
        """Gets the location of this DatacenterProperties.  # noqa: E501

        The physical location where the datacenter will be created. This will be where all of your servers live. Property cannot be modified after datacenter creation (disallowed in update requests).  # noqa: E501

        :return: The location of this DatacenterProperties.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this DatacenterProperties.

        The physical location where the datacenter will be created. This will be where all of your servers live. Property cannot be modified after datacenter creation (disallowed in update requests).  # noqa: E501

        :param location: The location of this DatacenterProperties.  # noqa: E501
        :type location: str
        """
        if self.local_vars_configuration.client_side_validation and location is None:  # noqa: E501
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    @property
    def name(self):
        """Gets the name of this DatacenterProperties.  # noqa: E501

        The name of the  resource.  # noqa: E501

        :return: The name of this DatacenterProperties.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DatacenterProperties.

        The name of the  resource.  # noqa: E501

        :param name: The name of this DatacenterProperties.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def sec_auth_protection(self):
        """Gets the sec_auth_protection of this DatacenterProperties.  # noqa: E501

        Boolean value representing if the data center requires extra protection, such as two-step verification.  # noqa: E501

        :return: The sec_auth_protection of this DatacenterProperties.  # noqa: E501
        :rtype: bool
        """
        return self._sec_auth_protection

    @sec_auth_protection.setter
    def sec_auth_protection(self, sec_auth_protection):
        """Sets the sec_auth_protection of this DatacenterProperties.

        Boolean value representing if the data center requires extra protection, such as two-step verification.  # noqa: E501

        :param sec_auth_protection: The sec_auth_protection of this DatacenterProperties.  # noqa: E501
        :type sec_auth_protection: bool
        """

        self._sec_auth_protection = sec_auth_protection

    @property
    def version(self):
        """Gets the version of this DatacenterProperties.  # noqa: E501

        The version of the data center; incremented with every change.  # noqa: E501

        :return: The version of this DatacenterProperties.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this DatacenterProperties.

        The version of the data center; incremented with every change.  # noqa: E501

        :param version: The version of this DatacenterProperties.  # noqa: E501
        :type version: int
        """

        self._version = version
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DatacenterProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DatacenterProperties):
            return True

        return self.to_dict() != other.to_dict()
